@@ -29,7 +29,7 @@ class SageHistoryExtension : public Cantor::HistoryExtension
     SageHistoryExtension( QObject* parent );
     ~SageHistoryExtension();
   public Q_SLOTS:
-    QString lastResult();
+    QString lastResult() Q_DECL_OVERRIDE;
 };
 
 class SageScriptExtension : public Cantor::ScriptExtension
@@ -38,9 +38,9 @@ class SageScriptExtension : public Cantor::ScriptExtension
     SageScriptExtension(QObject* parent);
     ~SageScriptExtension();
   public Q_SLOTS:
-    virtual QString runExternalScript(const QString& path);
-    virtual QString scriptFileFilter();
-    virtual QString highlightingMode();
+    QString runExternalScript(const QString& path) Q_DECL_OVERRIDE;
+    QString scriptFileFilter() Q_DECL_OVERRIDE;
+    QString highlightingMode() Q_DECL_OVERRIDE;
 };
 
 class SageCASExtension : public Cantor::CASExtension
@@ -50,9 +50,9 @@ class SageCASExtension : public Cantor::CASExtension
     ~SageCASExtension();
 
   public Q_SLOTS:
-    virtual QString solve(const QStringList& equations, const QStringList& variables);
-    virtual QString simplify(const QString& expression);
-    virtual QString expand(const QString& expression);
+    QString solve(const QStringList& equations, const QStringList& variables) Q_DECL_OVERRIDE;
+    QString simplify(const QString& expression) Q_DECL_OVERRIDE;
+    QString expand(const QString& expression) Q_DECL_OVERRIDE;
 
 };
 
@@ -63,10 +63,10 @@ class SageCalculusExtension : public Cantor::CalculusExtension
     ~SageCalculusExtension();
 
   public Q_SLOTS:
-    QString limit(const QString& expression, const QString& variable, const QString& limit);
-    QString differentiate(const QString& function,const QString& variable, int times);
-    QString integrate(const QString& function, const QString& variable);
-    QString integrate(const QString& function,const QString& variable, const QString& left, const QString& right);
+    QString limit(const QString& expression, const QString& variable, const QString& limit) Q_DECL_OVERRIDE;
+    QString differentiate(const QString& function,const QString& variable, int times) Q_DECL_OVERRIDE;
+    QString integrate(const QString& function, const QString& variable) Q_DECL_OVERRIDE;
+    QString integrate(const QString& function,const QString& variable, const QString& left, const QString& right) Q_DECL_OVERRIDE;
 };
 
 class SageLinearAlgebraExtension : public Cantor::LinearAlgebraExtension
@@ -77,18 +77,18 @@ class SageLinearAlgebraExtension : public Cantor::LinearAlgebraExtension
 
   public Q_SLOTS:
     //Commands to create Vectors/Matrices
-    QString createVector(const QStringList& entries, VectorType type);
-    QString nullVector(int size, VectorType type);
-    QString createMatrix(const Matrix& matrix);
-    QString identityMatrix(int size);
-    QString nullMatrix(int rows,int columns);
+    QString createVector(const QStringList& entries, VectorType type) Q_DECL_OVERRIDE;
+    QString nullVector(int size, VectorType type) Q_DECL_OVERRIDE;
+    QString createMatrix(const Matrix& matrix) Q_DECL_OVERRIDE;
+    QString identityMatrix(int size) Q_DECL_OVERRIDE;
+    QString nullMatrix(int rows,int columns) Q_DECL_OVERRIDE;
 
     //basic functions
-    QString rank(const QString& matrix);
-    QString invertMatrix(const QString& matrix);
-    QString charPoly(const QString& matrix);
-    QString eigenVectors(const QString& matrix);
-    QString eigenValues(const QString& matrix);
+    QString rank(const QString& matrix) Q_DECL_OVERRIDE;
+    QString invertMatrix(const QString& matrix) Q_DECL_OVERRIDE;
+    QString charPoly(const QString& matrix) Q_DECL_OVERRIDE;
+    QString eigenVectors(const QString& matrix) Q_DECL_OVERRIDE;
+    QString eigenValues(const QString& matrix) Q_DECL_OVERRIDE;
 };
 
 class SagePlotExtension : public Cantor::PlotExtension
@@ -97,8 +97,8 @@ class SagePlotExtension : public Cantor::PlotExtension
     SagePlotExtension(QObject* parent);
     ~SagePlotExtension();
   public Q_SLOTS:
-    QString plotFunction2d(const QString& function, const QString& variable, const QString& left, const QString& right);
-    QString plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2);
+    QString plotFunction2d(const QString& function, const QString& variable, const QString& left, const QString& right) Q_DECL_OVERRIDE;
+    QString plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2) Q_DECL_OVERRIDE;
 };
 
 class SagePackagingExtension : public Cantor::PackagingExtension
@@ -108,7 +108,7 @@ class SagePackagingExtension : public Cantor::PackagingExtension
     ~SagePackagingExtension();
 
   public Q_SLOTS:
-    virtual QString importPackage(const QString& module);
+    QString importPackage(const QString& module) Q_DECL_OVERRIDE;
 };
 
 #endif /* _SAGEEXTENSIONS_H */
